#ifndef GRAPH_DRAWER_H
#define GRAPH_DRAWER_H

/*!
  \file
  \brief Ot̕`

  \author Satofumi KAMIMURA

  $Id$
*/

#include "TypingMode.h"
#include <memory>


/*!
  \brief ^CsOт̃Ot`
*/
class GraphDrawer {
  GraphDrawer(void);
  GraphDrawer(const GraphDrawer& rhs);
  GraphDrawer& operator = (const GraphDrawer& rhs);

  struct pImpl;
  const std::auto_ptr<pImpl> pimpl;

public:
  /*!
    \brief RXgN^

    \param mode [i] `惂[h
  */
  explicit GraphDrawer(TypingMode mode);
  ~GraphDrawer(void);

  /*!
    \brief Ot`
  */
  bool drawGraph(void);

  /*!
    \brief R|[lg̔zu
  */
  void placeComponents(void);

  /*!
    \brief R|[lg̏
  */
  void removeComponents(void);

  /*!
    \brief sꂽԂ

    \retval true ꂽ
    \retval false ĂȂ
  */
  bool keyPressed(void);
};

#endif /* !GRAPH_DRAWER_H */
